@@ -55,7 +55,15 @@ void Pty::init()
     _xonXoff       = true;
     _utf8          = true;
 
+    setEraseChar(_eraseChar);
+    setFlowControlEnabled(_xonXoff);
+    setUtf8Mode(_utf8);
+
+    setWindowSize(_windowColumns, _windowLines);
+
+    setUseUtmp(true);
     setPtyChannels(KPtyProcess::AllChannels);
+
     connect(pty(), SIGNAL(readyRead()) , this , SLOT(dataReceived()));
 }
 
@@ -80,7 +88,7 @@ void Pty::dataReceived()
     emit receivedData(data.constData(), data.count());
 }
 
-void Pty::setWindowSize(int lines, int columns)
+void Pty::setWindowSize(int columns, int lines)
 {
     _windowColumns = columns;
     _windowLines = lines;
@@ -118,9 +126,10 @@ bool Pty::flowControlEnabled() const
         pty()->tcGetAttr(&ttmode);
         return ttmode.c_iflag & IXOFF &&
                ttmode.c_iflag & IXON;
+    } else {
+        kWarning() << "Unable to get flow control status, terminal not connected.";
+        return _xonXoff;
     }
-    kWarning() << "Unable to get flow control status, terminal not connected.";
-    return false;
 }
 
 void Pty::setUtf8Mode(bool enable)
@@ -150,6 +159,7 @@ void Pty::setEraseChar(char eChar)
         struct ::termios ttmode;
         pty()->tcGetAttr(&ttmode);
         ttmode.c_cc[VERASE] = eChar;
+
         if (!pty()->tcSetAttr(&ttmode))
             kWarning() << "Unable to set terminal attributes.";
     }
@@ -161,9 +171,10 @@ char Pty::eraseChar() const
         struct ::termios ttyAttributes;
         pty()->tcGetAttr(&ttyAttributes);
         return ttyAttributes.c_cc[VERASE];
+    } else {
+        kWarning() << "Unable to get erase char attribute, terminal not connected.";
+        return _eraseChar;
     }
-
-    return _eraseChar;
 }
 
 void Pty::setInitialWorkingDirectory(const QString& dir)
@@ -211,8 +222,7 @@ void Pty::addEnvironmentVariables(const QStringList& environmentVariables)
 
 int Pty::start(const QString& programName,
                const QStringList& programArguments,
-               const QStringList& environmentList,
-               bool addToUtmp)
+               const QStringList& environmentList)
 {
     clearProgram();
 
@@ -237,14 +247,6 @@ int Pty::start(const QString& programName,
     // BR:149300
     setEnv("LANGUAGE", QString(), false /* do not overwrite existing value if any */);
 
-    setUseUtmp(addToUtmp);
-
-    setFlowControlEnabled(_xonXoff);
-    setUtf8Mode(_utf8);
-    setEraseChar(_eraseChar);
-
-    setWindowSize(_windowLines, _windowColumns);
-
     KProcess::start();
 
     if (waitForStarted()) {
